## Typing stubs for pywin32

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`pywin32`](https://github.com/mhammond/pywin32) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `pywin32`. This version of
`types-pywin32` aims to provide accurate annotations for
`pywin32==308.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/pywin32`](https://github.com/python/typeshed/tree/main/stubs/pywin32)
directory.

This package was tested with
mypy 1.13.0,
pyright 1.1.389,
and pytype 2024.10.11.
It was generated from typeshed commit
[`fd6f10c8d1af630a1f3c2d1a22bacc5c054498cf`](https://github.com/python/typeshed/commit/fd6f10c8d1af630a1f3c2d1a22bacc5c054498cf).